@@ -1,5 +1,6 @@
 import salt.utils.parsers
-from salt.utils.verify import check_user, verify_log
+from salt.exceptions import SaltInvocationError
+from salt.utils.verify import check_user
 
 
 class SaltKey(salt.utils.parsers.SaltKeyOptionParser):
@@ -14,9 +15,11 @@ class SaltKey(salt.utils.parsers.SaltKeyOptionParser):
         import salt.key
 
         self.parse_args()
-
-        self.setup_logfile_logger()
-        verify_log(self.config)
+        if self.options.delete_all:
+            if self.args:
+                raise SaltInvocationError(
+                    "Delete all takes no arguments. Use -d to delete specified keys"
+                )
 
         key = salt.key.KeyCLI(self.config)
         if check_user(self.config["user"]):
