@@ -48,7 +48,7 @@ Tested on:
 """
 
 # TODO: look at event descriptions here:
-#       https://docs.saltstack.com/en/latest/topics/cloud/reactor.html
+#       https://docs.saltproject.io/en/latest/topics/cloud/reactor.html
 # TODO: support reboot? salt-cloud -a reboot vm1 vm2 vm2
 # TODO: by using metadata tags in the libvirt XML we could make provider only
 #       manage domains that we actually created
@@ -176,7 +176,7 @@ def list_nodes(call=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_nodes function must be called " "with -f or --function."
+            "The list_nodes function must be called with -f or --function."
         )
 
     providers = __opts__.get("providers", {})
@@ -212,7 +212,7 @@ def list_nodes_full(call=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_nodes_full function must be called " "with -f or --function."
+            "The list_nodes_full function must be called with -f or --function."
         )
 
     return list_nodes(call)
@@ -224,7 +224,7 @@ def list_nodes_select(call=None):
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_nodes_select function must be called " "with -f or --function."
+            "The list_nodes_select function must be called with -f or --function."
         )
 
     selection = __opts__.get("query.selection")
@@ -233,7 +233,11 @@ def list_nodes_select(call=None):
         raise SaltCloudSystemExit("query.selection not found in /etc/salt/cloud")
 
     # TODO: somewhat doubt the implementation of cloud.list_nodes_select
-    return salt.utils.cloud.list_nodes_select(list_nodes_full(), selection, call,)
+    return salt.utils.cloud.list_nodes_select(
+        list_nodes_full(),
+        selection,
+        call,
+    )
 
 
 def to_ip_addr_type(addr_type):
@@ -254,7 +258,7 @@ def get_domain_ips(domain, ip_source):
         log.info("Exception polling address %s", error)
         return ips
 
-    for (name, val) in addresses.items():
+    for name, val in addresses.items():
         if val["addrs"]:
             for addr in val["addrs"]:
                 tp = to_ip_addr_type(addr["type"])
@@ -328,7 +332,7 @@ def create(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "starting create",
-        "salt/cloud/{}/creating".format(name),
+        f"salt/cloud/{name}/creating",
         args=__utils__["cloud.filter_event"](
             "creating", vm_, ["name", "profile", "provider", "driver"]
         ),
@@ -341,7 +345,7 @@ def create(vm_):
     )
     if key_filename is not None and not os.path.isfile(key_filename):
         raise SaltCloudConfigError(
-            "The defined key_filename '{}' does not exist".format(key_filename)
+            f"The defined key_filename '{key_filename}' does not exist"
         )
     vm_["key_filename"] = key_filename
     # wait_for_instance requires private_key
@@ -370,7 +374,7 @@ def create(vm_):
             __utils__["cloud.fire_event"](
                 "event",
                 "requesting instance",
-                "salt/cloud/{}/requesting".format(name),
+                f"salt/cloud/{name}/requesting",
                 args={
                     "kwargs": __utils__["cloud.filter_event"](
                         "requesting", kwargs, list(kwargs)
@@ -388,7 +392,7 @@ def create(vm_):
                 description_elem = ElementTree.Element("description")
                 domain_xml.insert(0, description_elem)
             description = domain_xml.find("./description")
-            description.text = "Cloned from {}".format(base)
+            description.text = f"Cloned from {base}"
             domain_xml.remove(domain_xml.find("./uuid"))
 
             for iface_xml in domain_xml.findall("./devices/interface"):
@@ -422,9 +426,7 @@ def create(vm_):
                     # see if there is a path element that needs rewriting
                     if source_element and "path" in source_element.attrib:
                         path = source_element.attrib["path"]
-                        new_path = path.replace(
-                            "/domain-{}/".format(base), "/domain-{}/".format(name)
-                        )
+                        new_path = path.replace(f"/domain-{base}/", f"/domain-{name}/")
                         log.debug("Rewriting agent socket path to %s", new_path)
                         source_element.attrib["path"] = new_path
 
@@ -467,7 +469,7 @@ def create(vm_):
                     disk.find("./source").attrib["file"] = new_volume.path()
                 else:
                     raise SaltCloudExecutionFailure(
-                        "Disk type '{}' not supported".format(disk_type)
+                        f"Disk type '{disk_type}' not supported"
                     )
 
             clone_xml = salt.utils.stringutils.to_str(ElementTree.tostring(domain_xml))
@@ -511,7 +513,7 @@ def create(vm_):
         __utils__["cloud.fire_event"](
             "event",
             "created instance",
-            "salt/cloud/{}/created".format(name),
+            f"salt/cloud/{name}/created",
             args=__utils__["cloud.filter_event"](
                 "created", vm_, ["name", "profile", "provider", "driver"]
             ),
@@ -534,7 +536,7 @@ def do_cleanup(cleanup):
     behavior over time. Passed in volumes and domains are deleted, any errors
     are ignored. Used when cloning/provisioning a domain fails.
 
-    :param cleanup: list containing dictonaries with two keys: 'what' and 'item'.
+    :param cleanup: list containing dictionaries with two keys: 'what' and 'item'.
                     If 'what' is domain the 'item' is a libvirt domain object.
                     If 'what' is volume then the item is a libvirt volume object.
 
@@ -594,7 +596,7 @@ def destroy(name, call=None):
 
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     found = []
@@ -613,15 +615,15 @@ def destroy(name, call=None):
             pass
 
     if not found:
-        return "{} doesn't exist and can't be deleted".format(name)
+        return f"{name} doesn't exist and can't be deleted"
 
     if len(found) > 1:
-        return "{} doesn't identify a unique machine leaving things".format(name)
+        return f"{name} doesn't identify a unique machine leaving things"
 
     __utils__["cloud.fire_event"](
         "event",
         "destroying instance",
-        "salt/cloud/{}/destroying".format(name),
+        f"salt/cloud/{name}/destroying",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -632,7 +634,7 @@ def destroy(name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "destroyed instance",
-        "salt/cloud/{}/destroyed".format(name),
+        f"salt/cloud/{name}/destroyed",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -714,15 +716,15 @@ def find_pool_and_volume(conn, path):
         for v in sp.listAllVolumes():
             if v.path() == path:
                 return sp, v
-    raise SaltCloudNotFound("Could not find volume for path {}".format(path))
+    raise SaltCloudNotFound(f"Could not find volume for path {path}")
 
 
 def generate_new_name(orig_name):
     if "." not in orig_name:
-        return "{}-{}".format(orig_name, uuid.uuid1())
+        return f"{orig_name}-{uuid.uuid1()}"
 
     name, ext = orig_name.rsplit(".", 1)
-    return "{}-{}.{}".format(name, uuid.uuid1(), ext)
+    return f"{name}-{uuid.uuid1()}.{ext}"
 
 
 def get_domain_volumes(conn, domain):
