@@ -15,12 +15,20 @@ import salt.fileclient
 import salt.minion
 import salt.utils.data
 import salt.utils.files
+import salt.utils.functools
 import salt.utils.gzip_util
 import salt.utils.path
 import salt.utils.templates
 import salt.utils.url
 from salt.exceptions import CommandExecutionError
-from salt.loader.dunder import __file_client__
+from salt.loader.context import NamedLoaderContext
+from salt.loader.dunder import (
+    __context__,
+    __file_client__,
+    __grains__,
+    __opts__,
+    __pillar__,
+)
 
 log = logging.getLogger(__name__)
 
@@ -32,7 +40,7 @@ def _auth():
     Return the auth object
     """
     if "auth" not in __context__:
-        __context__["auth"] = salt.crypt.SAuth(__opts__)
+        __context__["auth"] = salt.crypt.SAuth(__opts__.value())
     return __context__["auth"]
 
 
@@ -41,7 +49,7 @@ def _gather_pillar(pillarenv, pillar_override):
     Whenever a state run starts, gather the pillar data fresh
     """
     pillar = salt.pillar.get_pillar(
-        __opts__,
+        __opts__.value(),
         __grains__.value(),
         __opts__["id"],
         __opts__["saltenv"],
@@ -115,7 +123,7 @@ def recv_chunked(dest, chunk, append=False, compressed=True, mode=None):
                 if os.path.isfile(dest):
                     return "Path exists and is a file"
             else:
-                return _error(exc.__str__())
+                return _error(str(exc))
         return True
 
     chunk = base64.b64decode(chunk)
@@ -126,12 +134,12 @@ def recv_chunked(dest, chunk, append=False, compressed=True, mode=None):
     except OSError as exc:
         if exc.errno != errno.ENOENT:
             # Parent dir does not exist, we need to create it
-            return _error(exc.__str__())
+            return _error(str(exc))
         try:
             os.makedirs(os.path.dirname(dest))
         except OSError as makedirs_exc:
             # Failed to make directory
-            return _error(makedirs_exc.__str__())
+            return _error(str(makedirs_exc))
         fh_ = salt.utils.files.fopen(dest, open_mode)  # pylint: disable=W8470
 
     try:
@@ -139,7 +147,7 @@ def recv_chunked(dest, chunk, append=False, compressed=True, mode=None):
         fh_.write(salt.utils.gzip_util.uncompress(chunk) if compressed else chunk)
     except OSError as exc:
         # Write failed
-        return _error(exc.__str__())
+        return _error(str(exc))
     else:
         # Write successful
         if not append and mode is not None:
@@ -148,8 +156,8 @@ def recv_chunked(dest, chunk, append=False, compressed=True, mode=None):
             log.debug("Setting mode for %s to %s", dest, mode)
             try:
                 os.chmod(dest, mode)
-            except OSError:
-                return _error(exc.__str__())
+            except OSError as exc:
+                return _error(str(exc))
         return True
     finally:
         try:
@@ -167,7 +175,7 @@ def _client():
     """
     if __file_client__:
         return __file_client__.value()
-    return salt.fileclient.get_file_client(__opts__)
+    return salt.fileclient.get_file_client(__opts__.value())
 
 
 def _render_filenames(path, dest, saltenv, template, **kw):
@@ -182,7 +190,7 @@ def _render_filenames(path, dest, saltenv, template, **kw):
     # render the path as a template using path_template_engine as the engine
     if template not in salt.utils.templates.TEMPLATE_REGISTRY:
         raise CommandExecutionError(
-            "Attempted to render file paths with unavailable engine {}".format(template)
+            f"Attempted to render file paths with unavailable engine {template}"
         )
 
     kwargs = {}
@@ -565,6 +573,9 @@ def cache_file(path, saltenv=None, source_hash=None, verify_ssl=True, use_etag=F
     return result
 
 
+cache_file_ssh = salt.utils.functools.alias_function(cache_file, "cache_file_ssh")
+
+
 def cache_dest(url, saltenv=None):
     """
     .. versionadded:: 3000
@@ -733,7 +744,7 @@ def list_states(saltenv=None):
     .. versionchanged:: 3005
         ``saltenv`` will use value from config if not explicitly set
 
-    List all of the available state modules in an environment
+    List all of the available state files in an environment
 
     CLI Example:
 
@@ -874,6 +885,9 @@ def hash_file(path, saltenv=None):
         return client.hash_file(path, saltenv)
 
 
+hash_file_ssh = salt.utils.functools.alias_function(hash_file, "hash_file_ssh")
+
+
 def stat_file(path, saltenv=None, octal=True):
     """
     .. versionchanged:: 3005
@@ -970,10 +984,14 @@ def push(path, keep_symlinks=False, upload_path=None, remove_source=False):
         "id": __opts__["id"],
         "path": load_path_list,
         "size": os.path.getsize(path),
-        "tok": auth.gen_token(b"salt"),
     }
 
-    with salt.channel.client.ReqChannel.factory(__opts__) as channel:
+    if isinstance(__opts__, NamedLoaderContext):
+        opts = __opts__.value()
+    else:
+        opts = __opts__
+
+    with salt.channel.client.ReqChannel.factory(opts) as channel:
         with salt.utils.files.fopen(path, "rb") as fp_:
             init_send = False
             while True:
