@@ -1,27 +1,17 @@
-# -*- coding: utf-8 -*-
 """
 Manage Linux kernel packages on APT-based systems
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import functools
 import logging
 import re
 
-try:
-    # Import Salt libs
-    from salt.ext import six
-    from salt.utils.versions import LooseVersion as _LooseVersion
-    from salt.ext.six.moves import filter
-    from salt.exceptions import CommandExecutionError
-
-    HAS_REQUIRED_LIBS = True
-except ImportError:
-    HAS_REQUIRED_LIBS = False
+from salt.exceptions import CommandExecutionError
+from salt.utils.versions import LooseVersion
 
 log = logging.getLogger(__name__)
 
-# Define the module's virtual name
+
 __virtualname__ = "kernelpkg"
 
 
@@ -29,10 +19,6 @@ def __virtual__():
     """
     Load this module on Debian-based systems only
     """
-
-    if not HAS_REQUIRED_LIBS:
-        return (False, "Required library could not be imported")
-
     if __grains__.get("os_family", "") in ("Kali", "Debian"):
         return __virtualname__
     elif __grains__.get("os_family", "") == "Cumulus":
@@ -67,7 +53,7 @@ def list_installed():
 
         salt '*' kernelpkg.list_installed
     """
-    pkg_re = re.compile(r"^{0}-[\d.-]+-{1}$".format(_package_prefix(), _kernel_type()))
+    pkg_re = re.compile(rf"^{_package_prefix()}-[\d.-]+-{_kernel_type()}$")
     pkgs = __salt__["pkg.list_pkgs"](versions_as_list=True)
     if pkgs is None:
         pkgs = []
@@ -78,12 +64,9 @@ def list_installed():
 
     prefix_len = len(_package_prefix()) + 1
 
-    if six.PY2:
-        return sorted([pkg[prefix_len:] for pkg in result], cmp=_cmp_version)
-    else:
-        return sorted(
-            [pkg[prefix_len:] for pkg in result], key=functools.cmp_to_key(_cmp_version)
-        )
+    return sorted(
+        (pkg[prefix_len:] for pkg in result), key=functools.cmp_to_key(_cmp_version)
+    )
 
 
 def latest_available():
@@ -96,14 +79,12 @@ def latest_available():
 
         salt '*' kernelpkg.latest_available
     """
-    result = __salt__["pkg.latest_version"](
-        "{0}-{1}".format(_package_prefix(), _kernel_type())
-    )
+    result = __salt__["pkg.latest_version"](f"{_package_prefix()}-{_kernel_type()}")
     if result == "":
         return latest_installed()
 
     version = re.match(r"^(\d+\.\d+\.\d+)\.(\d+)", result)
-    return "{0}-{1}-{2}".format(version.group(1), version.group(2), _kernel_type())
+    return f"{version.group(1)}-{version.group(2)}-{_kernel_type()}"
 
 
 def latest_installed():
@@ -141,7 +122,7 @@ def needs_reboot():
 
         salt '*' kernelpkg.needs_reboot
     """
-    return _LooseVersion(active()) < _LooseVersion(latest_installed())
+    return LooseVersion(active()) < LooseVersion(latest_installed())
 
 
 def upgrade(reboot=False, at_time=None):
@@ -169,9 +150,7 @@ def upgrade(reboot=False, at_time=None):
         chance to return, resulting in errors. A minimal delay (1 minute) is
         useful to ensure the result is delivered to the master.
     """
-    result = __salt__["pkg.install"](
-        name="{0}-{1}".format(_package_prefix(), latest_available())
-    )
+    result = __salt__["pkg.install"](name=f"{_package_prefix()}-{latest_available()}")
     _needs_reboot = needs_reboot()
 
     ret = {
@@ -200,7 +179,7 @@ def upgrade_available():
 
         salt '*' kernelpkg.upgrade_available
     """
-    return _LooseVersion(latest_available()) > _LooseVersion(latest_installed())
+    return LooseVersion(latest_available()) > LooseVersion(latest_installed())
 
 
 def remove(release):
@@ -219,14 +198,12 @@ def remove(release):
         salt '*' kernelpkg.remove 4.4.0-70-generic
     """
     if release not in list_installed():
-        raise CommandExecutionError(
-            "Kernel release '{0}' is not installed".format(release)
-        )
+        raise CommandExecutionError(f"Kernel release '{release}' is not installed")
 
     if release == active():
         raise CommandExecutionError("Active kernel cannot be removed")
 
-    target = "{0}-{1}".format(_package_prefix(), release)
+    target = f"{_package_prefix()}-{release}"
     log.info("Removing kernel package %s", target)
 
     __salt__["pkg.purge"](target)
@@ -286,8 +263,8 @@ def _cmp_version(item1, item2):
     """
     Compare function for package version sorting
     """
-    vers1 = _LooseVersion(item1)
-    vers2 = _LooseVersion(item2)
+    vers1 = LooseVersion(item1)
+    vers2 = LooseVersion(item2)
 
     if vers1 < vers2:
         return -1
