@@ -276,13 +276,11 @@ def gid_to_group(gid):
         salt '*' file.gid_to_group S-1-5-21-626487655-2533044672-482107328-1010
     """
     func_name = f"{__virtualname__}.gid_to_group"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; "
-            "see function docs for details.",
-            func_name,
-        )
-
+    log.info(
+        "The function %s should not be used on Windows systems; "
+        "see function docs for details.",
+        func_name,
+    )
     return uid_to_user(gid)
 
 
@@ -311,13 +309,11 @@ def group_to_gid(group):
         salt '*' file.group_to_gid administrators
     """
     func_name = f"{__virtualname__}.group_to_gid"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; "
-            "see function docs for details.",
-            func_name,
-        )
-
+    log.info(
+        "The function %s should not be used on Windows systems; "
+        "see function docs for details.",
+        func_name,
+    )
     if group is None:
         return ""
 
@@ -437,14 +433,12 @@ def get_gid(path, follow_symlinks=True):
         salt '*' file.get_gid c:\\temp\\test.txt
     """
     func_name = f"{__virtualname__}.get_gid"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; "
-            "see function docs for details. The value returned is the "
-            "uid.",
-            func_name,
-        )
-
+    log.info(
+        "The function %s should not be used on Windows systems; "
+        "see function docs for details. The value returned is the "
+        "uid.",
+        func_name,
+    )
     return get_uid(path, follow_symlinks)
 
 
@@ -484,26 +478,25 @@ def get_group(path, follow_symlinks=True):
         salt '*' file.get_group c:\\temp\\test.txt
     """
     func_name = f"{__virtualname__}.get_group"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; "
-            "see function docs for details. The value returned is the "
-            "user (owner).",
-            func_name,
-        )
-
+    log.info(
+        "The function %s should not be used on Windows systems; "
+        "see function docs for details. The value returned is the "
+        "user (owner).",
+        func_name,
+    )
     return get_user(path, follow_symlinks)
 
 
 def uid_to_user(uid):
     """
-    Convert a uid to a user name
+    Convert a User ID (uid) to a username
 
     Args:
         uid (str): The user id to lookup
 
     Returns:
-        str: The name of the user
+        str: The name of the user. The ``uid`` will be returned if there is no
+             corresponding username
 
     CLI Example:
 
@@ -639,14 +632,12 @@ def get_mode(path):
         raise CommandExecutionError(f"Path not found: {path}")
 
     func_name = f"{__virtualname__}.get_mode"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; "
-            "see function docs for details. The value returned is "
-            "always None.",
-            func_name,
-        )
-
+    log.info(
+        "The function %s should not be used on Windows systems; "
+        "see function docs for details. The value returned is "
+        "always None.",
+        func_name,
+    )
     return None
 
 
@@ -688,12 +679,11 @@ def lchown(path, user, group=None, pgroup=None):
     """
     if group:
         func_name = f"{__virtualname__}.lchown"
-        if __opts__.get("fun", "") == func_name:
-            log.info(
-                "The group parameter has no effect when using %s on "
-                "Windows systems; see function docs for details.",
-                func_name,
-            )
+        log.info(
+            "The group parameter has no effect when using %s on "
+            "Windows systems; see function docs for details.",
+            func_name,
+        )
         log.debug("win_file.py %s Ignoring the group parameter for %s", func_name, path)
         group = None
 
@@ -737,12 +727,11 @@ def chown(path, user, group=None, pgroup=None, follow_symlinks=True):
     # the group parameter is not used; only provided for API compatibility
     if group is not None:
         func_name = f"{__virtualname__}.chown"
-        if __opts__.get("fun", "") == func_name:
-            log.info(
-                "The group parameter has no effect when using %s on "
-                "Windows systems; see function docs for details.",
-                func_name,
-            )
+        log.info(
+            "The group parameter has no effect when using %s on "
+            "Windows systems; see function docs for details.",
+            func_name,
+        )
         log.debug("win_file.py %s Ignoring the group parameter for %s", func_name, path)
 
     if follow_symlinks and sys.getwindowsversion().major >= 6:
@@ -821,12 +810,11 @@ def chgrp(path, group):
         salt '*' file.chgrp c:\\temp\\test.txt administrators
     """
     func_name = f"{__virtualname__}.chgrp"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; see "
-            "function docs for details.",
-            func_name,
-        )
+    log.info(
+        "The function %s should not be used on Windows systems; see "
+        "function docs for details.",
+        func_name,
+    )
     log.debug("win_file.py %s Doing nothing for %s", func_name, path)
 
     return None
@@ -1314,14 +1302,12 @@ def set_mode(path, mode):
         salt '*' file.set_mode /etc/passwd 0644
     """
     func_name = f"{__virtualname__}.set_mode"
-    if __opts__.get("fun", "") == func_name:
-        log.info(
-            "The function %s should not be used on Windows systems; "
-            "see function docs for details. The value returned is "
-            "always None. Use set_perms instead.",
-            func_name,
-        )
-
+    log.info(
+        "The function %s should not be used on Windows systems; "
+        "see function docs for details. The value returned is "
+        "always None. Use set_perms instead.",
+        func_name,
+    )
     return get_mode(path)
 
 
@@ -1366,10 +1352,13 @@ def remove(path, force=False):
             # A file and a symlinked file are removed the same way
             path.unlink()
         else:
+            # Twangboy: This is for troubleshooting
+            is_dir = os.path.isdir(path)
+            exists = os.path.exists(path)
+            # This is a directory, list its contents and remove them recursively
             for child in path.iterdir():
                 # If it's a normal directory, recurse to remove its contents
                 remove(str(child), force)
-
             # rmdir will work now because the directory is empty
             path.rmdir()
     except OSError as exc:
