@@ -43,6 +43,10 @@ from salt.utils.odict import OrderedDict
 try:
     import M2Crypto
 
+    # These imports intended to be used from M2Crypto,
+    # but not loaded by-default with recent M2Crypto version.
+    from M2Crypto import ASN1, BIO, EVP, RSA, X509, m2  # pylint: disable=unused-import
+
     HAS_M2 = True
 except ImportError:
     HAS_M2 = False
@@ -96,7 +100,7 @@ def __virtual__():
         return (False, "Superseded, using x509_v2")
     if HAS_M2:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "The x509 modules are deprecated. Please migrate to the replacement "
             "modules (x509_v2). They are the default from Salt 3008 (Argon) onwards.",
         )
@@ -188,7 +192,7 @@ def _parse_openssl_req(csr_filename):
     """
     if not salt.utils.path.which("openssl"):
         raise salt.exceptions.SaltInvocationError("openssl binary not found in path")
-    cmd = "openssl req -text -noout -in {}".format(csr_filename)
+    cmd = f"openssl req -text -noout -in {csr_filename}"
 
     output = __salt__["cmd.run_stdout"](cmd)
 
@@ -231,7 +235,7 @@ def _parse_openssl_crl(crl_filename):
     """
     if not salt.utils.path.which("openssl"):
         raise salt.exceptions.SaltInvocationError("openssl binary not found in path")
-    cmd = "openssl crl -text -noout -in {}".format(crl_filename)
+    cmd = f"openssl crl -text -noout -in {crl_filename}"
 
     output = __salt__["cmd.run_stdout"](cmd)
 
@@ -316,7 +320,7 @@ def _dec2hex(decval):
     """
     Converts decimal values to nicely formatted hex strings
     """
-    return _pretty_hex("{:X}".format(decval))
+    return _pretty_hex(f"{decval:X}")
 
 
 def _isfile(path):
@@ -505,7 +509,7 @@ def get_pem_entry(text, pem_type=None):
                     pem_temp = pem_temp[pem_temp.index("-") :]
         text = "\n".join(pem_fixed)
 
-    errmsg = "PEM text not valid:\n{}".format(text)
+    errmsg = f"PEM text not valid:\n{text}"
     if pem_type:
         errmsg = "PEM does not contain a single entry of type {}:\n{}".format(
             pem_type, text
@@ -824,7 +828,7 @@ def write_pem(text, path, overwrite=True, pem_type=None):
             _fp.write(salt.utils.stringutils.to_str(text))
             if pem_type and pem_type == "CERTIFICATE" and _dhparams:
                 _fp.write(salt.utils.stringutils.to_str(_dhparams))
-    return "PEM written to {}".format(path)
+    return f"PEM written to {path}"
 
 
 def create_private_key(
@@ -1130,7 +1134,7 @@ def get_signing_policy(signing_policy_name):
     """
     signing_policy = _get_signing_policy(signing_policy_name)
     if not signing_policy:
-        return "Signing policy {} does not exist.".format(signing_policy_name)
+        return f"Signing policy {signing_policy_name} does not exist."
     if isinstance(signing_policy, list):
         dict_ = {}
         for item in signing_policy:
