@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage Lambda Functions
 =======================
@@ -60,9 +59,6 @@ config:
 
 """
 
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import hashlib
 import logging
 import os
@@ -73,9 +69,6 @@ import salt.utils.files
 import salt.utils.json
 from salt.exceptions import SaltInvocationError
 
-# Import Salt Libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -225,22 +218,23 @@ def function_present(
     ret = {"name": FunctionName, "result": True, "comment": "", "changes": {}}
 
     if Permissions is not None:
-        if isinstance(Permissions, six.string_types):
+        if isinstance(Permissions, str):
             Permissions = salt.utils.json.loads(Permissions)
-        required_keys = set(("Action", "Principal"))
-        optional_keys = set(("SourceArn", "SourceAccount", "Qualifier"))
-        for sid, permission in six.iteritems(Permissions):
+        required_keys = {"Action", "Principal"}
+        optional_keys = {"SourceArn", "SourceAccount", "Qualifier"}
+        for sid, permission in Permissions.items():
             keyset = set(permission.keys())
             if not keyset.issuperset(required_keys):
                 raise SaltInvocationError(
-                    "{0} are required for each permission "
-                    "specification".format(", ".join(required_keys))
+                    "{} are required for each permission specification".format(
+                        ", ".join(required_keys)
+                    )
                 )
             keyset = keyset - required_keys
             keyset = keyset - optional_keys
             if bool(keyset):
                 raise SaltInvocationError(
-                    "Invalid permission value {0}".format(", ".join(keyset))
+                    "Invalid permission value {}".format(", ".join(keyset))
                 )
 
     r = __salt__["boto_lambda.function_exists"](
@@ -249,14 +243,12 @@ def function_present(
 
     if "error" in r:
         ret["result"] = False
-        ret["comment"] = "Failed to create function: " "{0}.".format(
-            r["error"]["message"]
-        )
+        ret["comment"] = "Failed to create function: {}.".format(r["error"]["message"])
         return ret
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Function {0} is set to be created.".format(FunctionName)
+            ret["comment"] = f"Function {FunctionName} is set to be created."
             ret["result"] = None
             return ret
         r = __salt__["boto_lambda.create_function"](
@@ -282,13 +274,13 @@ def function_present(
         )
         if not r.get("created"):
             ret["result"] = False
-            ret["comment"] = "Failed to create function: " "{0}.".format(
+            ret["comment"] = "Failed to create function: {}.".format(
                 r["error"]["message"]
             )
             return ret
 
         if Permissions:
-            for sid, permission in six.iteritems(Permissions):
+            for sid, permission in Permissions.items():
                 r = __salt__["boto_lambda.add_permission"](
                     FunctionName=FunctionName,
                     StatementId=sid,
@@ -296,11 +288,11 @@ def function_present(
                     key=key,
                     keyid=keyid,
                     profile=profile,
-                    **permission
+                    **permission,
                 )
                 if not r.get("updated"):
                     ret["result"] = False
-                    ret["comment"] = "Failed to create function: " "{0}.".format(
+                    ret["comment"] = "Failed to create function: {}.".format(
                         r["error"]["message"]
                     )
 
@@ -312,11 +304,11 @@ def function_present(
         )["permissions"]
         ret["changes"]["old"] = {"function": None}
         ret["changes"]["new"] = _describe
-        ret["comment"] = "Function {0} created.".format(FunctionName)
+        ret["comment"] = f"Function {FunctionName} created."
         return ret
 
     ret["comment"] = os.linesep.join(
-        [ret["comment"], "Function {0} is present.".format(FunctionName)]
+        [ret["comment"], f"Function {FunctionName} is present."]
     )
     ret["changes"] = {}
     # function exists, ensure config matches
@@ -380,11 +372,11 @@ def _get_role_arn(name, region=None, key=None, keyid=None, profile=None):
     account_id = __salt__["boto_iam.get_account_id"](
         region=region, key=key, keyid=keyid, profile=profile
     )
-    return "arn:aws:iam::{0}:role/{1}".format(account_id, name)
+    return f"arn:aws:iam::{account_id}:role/{name}"
 
 
 def _resolve_vpcconfig(conf, region=None, key=None, keyid=None, profile=None):
-    if isinstance(conf, six.string_types):
+    if isinstance(conf, str):
         conf = salt.utils.json.loads(conf)
     if not conf:
         # if the conf is None, we should explicitly set the VpcConfig to
@@ -438,7 +430,7 @@ def _function_config_present(
         "MemorySize": MemorySize,
     }
 
-    for key, val in six.iteritems(options):
+    for key, val in options.items():
         if func[key] != val:
             need_update = True
             ret["changes"].setdefault("old", {})[key] = func[key]
@@ -468,7 +460,7 @@ def _function_config_present(
             [ret["comment"], "Function config to be modified"]
         )
         if __opts__["test"]:
-            ret["comment"] = "Function {0} set to be modified.".format(FunctionName)
+            ret["comment"] = f"Function {FunctionName} set to be modified."
             ret["result"] = None
             return ret
         _r = __salt__["boto_lambda.update_function_config"](
@@ -489,7 +481,7 @@ def _function_config_present(
         )
         if not _r.get("updated"):
             ret["result"] = False
-            ret["comment"] = "Failed to update function: " "{0}.".format(
+            ret["comment"] = "Failed to update function: {}.".format(
                 _r["error"]["message"]
             )
             ret["changes"] = {}
@@ -509,7 +501,7 @@ def _function_code_present(
             dlZipFile = __salt__["cp.cache_file"](path=ZipFile)
             if dlZipFile is False:
                 ret["result"] = False
-                ret["comment"] = "Failed to cache ZipFile `{0}`.".format(ZipFile)
+                ret["comment"] = f"Failed to cache ZipFile `{ZipFile}`."
                 return ret
             ZipFile = dlZipFile
         size = os.path.getsize(ZipFile)
@@ -529,7 +521,7 @@ def _function_code_present(
         update = True
     if update:
         if __opts__["test"]:
-            ret["comment"] = "Function {0} set to be modified.".format(FunctionName)
+            ret["comment"] = f"Function {FunctionName} set to be modified."
             ret["result"] = None
             return ret
         ret["changes"]["old"] = {
@@ -549,7 +541,7 @@ def _function_code_present(
         )
         if not func.get("updated"):
             ret["result"] = False
-            ret["comment"] = "Failed to update function: " "{0}.".format(
+            ret["comment"] = "Failed to update function: {}.".format(
                 func["error"]["message"]
             )
             ret["changes"] = {}
@@ -587,10 +579,10 @@ def _function_permissions_present(
             [ret["comment"], "Function permissions to be modified"]
         )
         if __opts__["test"]:
-            ret["comment"] = "Function {0} set to be modified.".format(FunctionName)
+            ret["comment"] = f"Function {FunctionName} set to be modified."
             ret["result"] = None
             return ret
-        for sid, diff in six.iteritems(diffs):
+        for sid, diff in diffs.items():
             if diff.get("old", "") != "":
                 # There's a permssion that needs to be removed
                 _r = __salt__["boto_lambda.remove_permission"](
@@ -616,7 +608,7 @@ def _function_permissions_present(
                     key=key,
                     keyid=keyid,
                     profile=profile,
-                    **diff["new"]
+                    **diff["new"],
                 )
                 ret["changes"].setdefault("new", {}).setdefault("Permissions", {})[
                     sid
@@ -628,7 +620,7 @@ def _function_permissions_present(
                     oldperms[sid] = {}
             if not _r.get("updated"):
                 ret["result"] = False
-                ret["comment"] = "Failed to update function: " "{0}.".format(
+                ret["comment"] = "Failed to update function: {}.".format(
                     _r["error"]["message"]
                 )
                 ret["changes"] = {}
@@ -668,15 +660,15 @@ def function_absent(
     )
     if "error" in r:
         ret["result"] = False
-        ret["comment"] = "Failed to delete function: {0}.".format(r["error"]["message"])
+        ret["comment"] = "Failed to delete function: {}.".format(r["error"]["message"])
         return ret
 
     if r and not r["exists"]:
-        ret["comment"] = "Function {0} does not exist.".format(FunctionName)
+        ret["comment"] = f"Function {FunctionName} does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Function {0} is set to be removed.".format(FunctionName)
+        ret["comment"] = f"Function {FunctionName} is set to be removed."
         ret["result"] = None
         return ret
     r = __salt__["boto_lambda.delete_function"](
@@ -684,13 +676,11 @@ def function_absent(
     )
     if not r["deleted"]:
         ret["result"] = False
-        ret["comment"] = "Failed to delete function: " "{0}.".format(
-            r["error"]["message"]
-        )
+        ret["comment"] = "Failed to delete function: {}.".format(r["error"]["message"])
         return ret
     ret["changes"]["old"] = {"function": FunctionName}
     ret["changes"]["new"] = {"function": None}
-    ret["comment"] = "Function {0} deleted.".format(FunctionName)
+    ret["comment"] = f"Function {FunctionName} deleted."
     return ret
 
 
@@ -750,12 +740,12 @@ def alias_present(
 
     if "error" in r:
         ret["result"] = False
-        ret["comment"] = "Failed to create alias: " "{0}.".format(r["error"]["message"])
+        ret["comment"] = "Failed to create alias: {}.".format(r["error"]["message"])
         return ret
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Alias {0} is set to be created.".format(Name)
+            ret["comment"] = f"Alias {Name} is set to be created."
             ret["result"] = None
             return ret
         r = __salt__["boto_lambda.create_alias"](
@@ -770,21 +760,17 @@ def alias_present(
         )
         if not r.get("created"):
             ret["result"] = False
-            ret["comment"] = "Failed to create alias: " "{0}.".format(
-                r["error"]["message"]
-            )
+            ret["comment"] = "Failed to create alias: {}.".format(r["error"]["message"])
             return ret
         _describe = __salt__["boto_lambda.describe_alias"](
             FunctionName, Name, region=region, key=key, keyid=keyid, profile=profile
         )
         ret["changes"]["old"] = {"alias": None}
         ret["changes"]["new"] = _describe
-        ret["comment"] = "Alias {0} created.".format(Name)
+        ret["comment"] = f"Alias {Name} created."
         return ret
 
-    ret["comment"] = os.linesep.join(
-        [ret["comment"], "Alias {0} is present.".format(Name)]
-    )
+    ret["comment"] = os.linesep.join([ret["comment"], f"Alias {Name} is present."])
     ret["changes"] = {}
     _describe = __salt__["boto_lambda.describe_alias"](
         FunctionName, Name, region=region, key=key, keyid=keyid, profile=profile
@@ -793,7 +779,7 @@ def alias_present(
     need_update = False
     options = {"FunctionVersion": FunctionVersion, "Description": Description}
 
-    for key, val in six.iteritems(options):
+    for key, val in options.items():
         if _describe[key] != val:
             need_update = True
             ret["changes"].setdefault("old", {})[key] = _describe[key]
@@ -803,7 +789,7 @@ def alias_present(
             [ret["comment"], "Alias config to be modified"]
         )
         if __opts__["test"]:
-            ret["comment"] = "Alias {0} set to be modified.".format(Name)
+            ret["comment"] = f"Alias {Name} set to be modified."
             ret["result"] = None
             return ret
         _r = __salt__["boto_lambda.update_alias"](
@@ -818,7 +804,7 @@ def alias_present(
         )
         if not _r.get("updated"):
             ret["result"] = False
-            ret["comment"] = "Failed to update alias: " "{0}.".format(
+            ret["comment"] = "Failed to update alias: {}.".format(
                 _r["error"]["message"]
             )
             ret["changes"] = {}
@@ -861,15 +847,15 @@ def alias_absent(
     )
     if "error" in r:
         ret["result"] = False
-        ret["comment"] = "Failed to delete alias: " "{0}.".format(r["error"]["message"])
+        ret["comment"] = "Failed to delete alias: {}.".format(r["error"]["message"])
         return ret
 
     if r and not r["exists"]:
-        ret["comment"] = "Alias {0} does not exist.".format(Name)
+        ret["comment"] = f"Alias {Name} does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Alias {0} is set to be removed.".format(Name)
+        ret["comment"] = f"Alias {Name} is set to be removed."
         ret["result"] = None
         return ret
     r = __salt__["boto_lambda.delete_alias"](
@@ -877,11 +863,11 @@ def alias_absent(
     )
     if not r["deleted"]:
         ret["result"] = False
-        ret["comment"] = "Failed to delete alias: " "{0}.".format(r["error"]["message"])
+        ret["comment"] = "Failed to delete alias: {}.".format(r["error"]["message"])
         return ret
     ret["changes"]["old"] = {"alias": Name}
     ret["changes"]["new"] = {"alias": None}
-    ret["comment"] = "Alias {0} deleted.".format(Name)
+    ret["comment"] = f"Alias {Name} deleted."
     return ret
 
 
@@ -896,7 +882,7 @@ def _get_function_arn(name, region=None, key=None, keyid=None, profile=None):
         region = profile["region"]
     if region is None:
         region = "us-east-1"
-    return "arn:aws:lambda:{0}:{1}:function:{2}".format(region, account_id, name)
+    return f"arn:aws:lambda:{region}:{account_id}:function:{name}"
 
 
 def event_source_mapping_present(
@@ -973,14 +959,14 @@ def event_source_mapping_present(
 
     if "error" in r:
         ret["result"] = False
-        ret["comment"] = "Failed to create event source mapping: " "{0}.".format(
+        ret["comment"] = "Failed to create event source mapping: {}.".format(
             r["error"]["message"]
         )
         return ret
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Event source mapping {0} is set " "to be created.".format(
+            ret["comment"] = "Event source mapping {} is set to be created.".format(
                 FunctionName
             )
             ret["result"] = None
@@ -998,7 +984,7 @@ def event_source_mapping_present(
         )
         if not r.get("created"):
             ret["result"] = False
-            ret["comment"] = "Failed to create event source mapping: " "{0}.".format(
+            ret["comment"] = "Failed to create event source mapping: {}.".format(
                 r["error"]["message"]
             )
             return ret
@@ -1013,7 +999,7 @@ def event_source_mapping_present(
         ret["name"] = _describe["event_source_mapping"]["UUID"]
         ret["changes"]["old"] = {"event_source_mapping": None}
         ret["changes"]["new"] = _describe
-        ret["comment"] = "Event source mapping {0} " "created.".format(ret["name"])
+        ret["comment"] = "Event source mapping {} created.".format(ret["name"])
         return ret
 
     ret["comment"] = os.linesep.join(
@@ -1032,7 +1018,7 @@ def event_source_mapping_present(
     need_update = False
     options = {"BatchSize": BatchSize}
 
-    for key, val in six.iteritems(options):
+    for key, val in options.items():
         if _describe[key] != val:
             need_update = True
             ret["changes"].setdefault("old", {})[key] = _describe[key]
@@ -1052,7 +1038,7 @@ def event_source_mapping_present(
             [ret["comment"], "Event source mapping to be modified"]
         )
         if __opts__["test"]:
-            ret["comment"] = "Event source mapping {0} set to be modified.".format(
+            ret["comment"] = "Event source mapping {} set to be modified.".format(
                 _describe["UUID"]
             )
             ret["result"] = None
@@ -1069,7 +1055,7 @@ def event_source_mapping_present(
         )
         if not _r.get("updated"):
             ret["result"] = False
-            ret["comment"] = "Failed to update mapping: " "{0}.".format(
+            ret["comment"] = "Failed to update mapping: {}.".format(
                 _r["error"]["message"]
             )
             ret["changes"] = {}
@@ -1117,7 +1103,7 @@ def event_source_mapping_absent(
     )
     if "error" in desc:
         ret["result"] = False
-        ret["comment"] = "Failed to delete event source mapping: " "{0}.".format(
+        ret["comment"] = "Failed to delete event source mapping: {}.".format(
             desc["error"]["message"]
         )
         return ret
@@ -1141,7 +1127,7 @@ def event_source_mapping_absent(
     )
     if not r["deleted"]:
         ret["result"] = False
-        ret["comment"] = "Failed to delete event source mapping: {0}.".format(
+        ret["comment"] = "Failed to delete event source mapping: {}.".format(
             r["error"]["message"]
         )
         return ret
