@@ -2,6 +2,7 @@
 A module written originally by Armin Ronacher to manage file transfers in an
 atomic way
 """
+
 import errno
 import os
 import random
@@ -10,12 +11,17 @@ import sys
 import tempfile
 import time
 
+import salt.utils.files
 import salt.utils.win_dacl
 
 CAN_RENAME_OPEN_FILE = False
 if os.name == "nt":  # pragma: no cover
-    _rename = lambda src, dst: False  # pylint: disable=C0103
-    _rename_atomic = lambda src, dst: False  # pylint: disable=C0103
+
+    def _rename(src, dst):
+        return False
+
+    def _rename_atomic(src, dst):
+        return False
 
     try:
         import ctypes
@@ -90,7 +96,7 @@ if os.name == "nt":  # pragma: no cover
         except OSError as err:
             if err.errno != errno.EEXIST:
                 raise
-            old = "{}-{:08x}".format(dst, random.randint(0, sys.maxint))
+            old = f"{dst}-{random.randint(0, sys.maxint):08x}"
             os.rename(dst, old)
             os.rename(src, dst)
             try:
@@ -98,7 +104,6 @@ if os.name == "nt":  # pragma: no cover
             except Exception:  # pylint: disable=broad-except
                 pass
 
-
 else:
     atomic_rename = os.rename  # pylint: disable=C0103
     CAN_RENAME_OPEN_FILE = True
@@ -124,15 +129,19 @@ class _AtomicWFile:
         if self._fh.closed:
             return
         self._fh.close()
-        if os.path.isfile(self._filename):
-            if salt.utils.win_dacl.HAS_WIN32:
+        if salt.utils.win_dacl.HAS_WIN32:
+            if os.path.isfile(self._filename):
                 salt.utils.win_dacl.copy_security(
                     source=self._filename, target=self._tmp_filename
                 )
-            else:
+        else:
+            if os.path.isfile(self._filename):
                 shutil.copymode(self._filename, self._tmp_filename)
                 st = os.stat(self._filename)
                 os.chown(self._tmp_filename, st.st_uid, st.st_gid)
+            else:
+                # chmod file to default mode based on umask
+                os.chmod(self._tmp_filename, 0o666 & ~salt.utils.files.get_umask())
         atomic_rename(self._tmp_filename, self._filename)
 
     def __exit__(self, exc_type, exc_value, traceback):
