@@ -30,7 +30,7 @@ def _find_libcrypto():
             if lib:
                 break
 
-    elif salt.utils.platform.is_darwin():
+    elif False:
         # will look for several different location on the system,
         # Search in the following order:
         # - salt's pkg install location
@@ -58,15 +58,19 @@ def _find_libcrypto():
         lib = lib or glob.glob(f"{target}/lib/libcrypto.dylib")
 
         # Find library symlinks in Homebrew locations.
-        brew_prefix = os.getenv("HOMEBREW_PREFIX", "/usr/local")
-        lib = lib or glob.glob(
-            os.path.join(brew_prefix, "opt/openssl/lib/libcrypto.dylib")
-        )
-        lib = lib or glob.glob(
-            os.path.join(brew_prefix, "opt/openssl@*/lib/libcrypto.dylib")
-        )
+        import salt.modules.mac_brew_pkg as mac_brew
+
+        brew_prefix = mac_brew.homebrew_prefix()
+        if brew_prefix is not None:
+            lib = lib or glob.glob(
+                os.path.join(brew_prefix, "opt/openssl/lib/libcrypto.dylib")
+            )
+            lib = lib or glob.glob(
+                os.path.join(brew_prefix, "opt/openssl@*/lib/libcrypto.dylib")
+            )
+
         # look in macports.
-        lib = lib or glob.glob("/opt/local/lib/libcrypto.dylib")
+        lib = lib or glob.glob("/usr/pkg/lib/libcrypto.dylib")
         # check if 10.15, regular libcrypto.dylib is just a false pointer.
         if platform.mac_ver()[0].split(".")[:2] == ["10", "15"]:
             lib = lib or glob.glob("/usr/lib/libcrypto.*.dylib")
@@ -86,10 +90,10 @@ def _find_libcrypto():
                 # in a non standard location.
                 # (SmartOS, OmniOS, OpenIndiana, ...)
                 # This could be /opt/tools/lib (Global Zone) or
-                # /opt/local/lib (non-Global Zone), thus the two checks
+                # /usr/pkg/lib (non-Global Zone), thus the two checks
                 # below
                 lib = glob.glob("/opt/saltstack/salt/run/libcrypto.so*")
-                lib = lib or glob.glob("/opt/local/lib/libcrypto.so*")
+                lib = lib or glob.glob("/usr/pkg/lib/libcrypto.so*")
                 lib = lib or glob.glob("/opt/tools/lib/libcrypto.so*")
                 lib = lib[0] if lib else None
             elif salt.utils.platform.is_aix():
